/********************************************************************************
** Form generated from reading UI file 'encodervorbisconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENCODERVORBISCONFIG_H
#define UI_ENCODERVORBISCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EncoderVorbisConfig
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *kcfg_vorbis_enc_method;
    QFormLayout *formLayout_2;
    QRadioButton *vorbis_enc_bitrate;
    QRadioButton *vorbis_enc_quality;
    QGroupBox *vorbis_bitrate_settings;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_set_vorbis_max_br;
    QComboBox *kcfg_vorbis_max_br;
    QSpacerItem *horizontalSpacer;
    QComboBox *kcfg_vorbis_min_br;
    QCheckBox *kcfg_set_vorbis_nominal_br;
    QCheckBox *kcfg_set_vorbis_min_br;
    QComboBox *kcfg_vorbis_nominal_br;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *vorbis_quality_settings;
    QFormLayout *formLayout;
    QLabel *qualityLabel;
    QDoubleSpinBox *kcfg_vorbis_quality;
    QGroupBox *GroupBox193;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *kcfg_vorbis_comments;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *spacer9;

    void setupUi(QWidget *EncoderVorbisConfig)
    {
        if (EncoderVorbisConfig->objectName().isEmpty())
            EncoderVorbisConfig->setObjectName("EncoderVorbisConfig");
        EncoderVorbisConfig->resize(501, 408);
        vboxLayout = new QVBoxLayout(EncoderVorbisConfig);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_vorbis_enc_method = new QGroupBox(EncoderVorbisConfig);
        kcfg_vorbis_enc_method->setObjectName("kcfg_vorbis_enc_method");
        kcfg_vorbis_enc_method->setFlat(true);
        formLayout_2 = new QFormLayout(kcfg_vorbis_enc_method);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout_2->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        vorbis_enc_bitrate = new QRadioButton(kcfg_vorbis_enc_method);
        vorbis_enc_bitrate->setObjectName("vorbis_enc_bitrate");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, vorbis_enc_bitrate);

        vorbis_enc_quality = new QRadioButton(kcfg_vorbis_enc_method);
        vorbis_enc_quality->setObjectName("vorbis_enc_quality");
        vorbis_enc_quality->setChecked(true);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, vorbis_enc_quality);


        vboxLayout->addWidget(kcfg_vorbis_enc_method);

        vorbis_bitrate_settings = new QGroupBox(EncoderVorbisConfig);
        vorbis_bitrate_settings->setObjectName("vorbis_bitrate_settings");
        vorbis_bitrate_settings->setEnabled(true);
        vorbis_bitrate_settings->setFlat(true);
        gridLayout = new QGridLayout(vorbis_bitrate_settings);
        gridLayout->setObjectName("gridLayout");
        kcfg_set_vorbis_max_br = new QCheckBox(vorbis_bitrate_settings);
        kcfg_set_vorbis_max_br->setObjectName("kcfg_set_vorbis_max_br");
        kcfg_set_vorbis_max_br->setEnabled(true);

        gridLayout->addWidget(kcfg_set_vorbis_max_br, 1, 1, 1, 1);

        kcfg_vorbis_max_br = new QComboBox(vorbis_bitrate_settings);
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->addItem(QString());
        kcfg_vorbis_max_br->setObjectName("kcfg_vorbis_max_br");
        kcfg_vorbis_max_br->setEnabled(false);

        gridLayout->addWidget(kcfg_vorbis_max_br, 1, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        kcfg_vorbis_min_br = new QComboBox(vorbis_bitrate_settings);
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->addItem(QString());
        kcfg_vorbis_min_br->setObjectName("kcfg_vorbis_min_br");
        kcfg_vorbis_min_br->setEnabled(false);

        gridLayout->addWidget(kcfg_vorbis_min_br, 0, 2, 1, 1);

        kcfg_set_vorbis_nominal_br = new QCheckBox(vorbis_bitrate_settings);
        kcfg_set_vorbis_nominal_br->setObjectName("kcfg_set_vorbis_nominal_br");
        kcfg_set_vorbis_nominal_br->setChecked(true);

        gridLayout->addWidget(kcfg_set_vorbis_nominal_br, 2, 1, 1, 1);

        kcfg_set_vorbis_min_br = new QCheckBox(vorbis_bitrate_settings);
        kcfg_set_vorbis_min_br->setObjectName("kcfg_set_vorbis_min_br");
        kcfg_set_vorbis_min_br->setEnabled(true);

        gridLayout->addWidget(kcfg_set_vorbis_min_br, 0, 1, 1, 1);

        kcfg_vorbis_nominal_br = new QComboBox(vorbis_bitrate_settings);
        kcfg_vorbis_nominal_br->addItem(QString());
        kcfg_vorbis_nominal_br->addItem(QString());
        kcfg_vorbis_nominal_br->addItem(QString());
        kcfg_vorbis_nominal_br->addItem(QString());
        kcfg_vorbis_nominal_br->addItem(QString());
        kcfg_vorbis_nominal_br->setObjectName("kcfg_vorbis_nominal_br");

        gridLayout->addWidget(kcfg_vorbis_nominal_br, 2, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 3, 1, 1);


        vboxLayout->addWidget(vorbis_bitrate_settings);

        vorbis_quality_settings = new QGroupBox(EncoderVorbisConfig);
        vorbis_quality_settings->setObjectName("vorbis_quality_settings");
        vorbis_quality_settings->setFlat(true);
        formLayout = new QFormLayout(vorbis_quality_settings);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        qualityLabel = new QLabel(vorbis_quality_settings);
        qualityLabel->setObjectName("qualityLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, qualityLabel);

        kcfg_vorbis_quality = new QDoubleSpinBox(vorbis_quality_settings);
        kcfg_vorbis_quality->setObjectName("kcfg_vorbis_quality");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_vorbis_quality->sizePolicy().hasHeightForWidth());
        kcfg_vorbis_quality->setSizePolicy(sizePolicy);
        kcfg_vorbis_quality->setDecimals(1);
        kcfg_vorbis_quality->setMinimum(0.000000000000000);
        kcfg_vorbis_quality->setMaximum(0.000000000000000);
        kcfg_vorbis_quality->setValue(0.000000000000000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_vorbis_quality);


        vboxLayout->addWidget(vorbis_quality_settings);

        GroupBox193 = new QGroupBox(EncoderVorbisConfig);
        GroupBox193->setObjectName("GroupBox193");
        GroupBox193->setFlat(true);
        horizontalLayout = new QHBoxLayout(GroupBox193);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        kcfg_vorbis_comments = new QCheckBox(GroupBox193);
        kcfg_vorbis_comments->setObjectName("kcfg_vorbis_comments");
        kcfg_vorbis_comments->setEnabled(true);

        horizontalLayout->addWidget(kcfg_vorbis_comments);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        vboxLayout->addWidget(GroupBox193);

        spacer9 = new QSpacerItem(20, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer9);

        QWidget::setTabOrder(kcfg_set_vorbis_min_br, kcfg_set_vorbis_max_br);
        QWidget::setTabOrder(kcfg_set_vorbis_max_br, kcfg_set_vorbis_nominal_br);
        QWidget::setTabOrder(kcfg_set_vorbis_nominal_br, kcfg_vorbis_min_br);
        QWidget::setTabOrder(kcfg_vorbis_min_br, kcfg_vorbis_max_br);
        QWidget::setTabOrder(kcfg_vorbis_max_br, kcfg_vorbis_nominal_br);
        QWidget::setTabOrder(kcfg_vorbis_nominal_br, kcfg_vorbis_comments);

        retranslateUi(EncoderVorbisConfig);
        QObject::connect(vorbis_enc_bitrate, &QRadioButton::toggled, vorbis_bitrate_settings, &QGroupBox::setVisible);
        QObject::connect(vorbis_enc_quality, &QRadioButton::toggled, vorbis_quality_settings, &QGroupBox::setVisible);
        QObject::connect(kcfg_set_vorbis_nominal_br, &QCheckBox::toggled, kcfg_set_vorbis_max_br, &QCheckBox::setDisabled);
        QObject::connect(kcfg_set_vorbis_nominal_br, &QCheckBox::toggled, kcfg_set_vorbis_min_br, &QCheckBox::setDisabled);
        QObject::connect(kcfg_set_vorbis_nominal_br, &QCheckBox::toggled, kcfg_vorbis_nominal_br, &QComboBox::setEnabled);
        QObject::connect(kcfg_set_vorbis_max_br, &QCheckBox::toggled, kcfg_vorbis_max_br, &QComboBox::setEnabled);
        QObject::connect(kcfg_set_vorbis_min_br, &QCheckBox::toggled, kcfg_vorbis_min_br, &QComboBox::setEnabled);
        QObject::connect(kcfg_set_vorbis_max_br, &QCheckBox::toggled, kcfg_set_vorbis_nominal_br, &QCheckBox::setDisabled);
        QObject::connect(kcfg_set_vorbis_min_br, &QCheckBox::toggled, kcfg_set_vorbis_nominal_br, &QCheckBox::setDisabled);

        kcfg_vorbis_max_br->setCurrentIndex(13);
        kcfg_vorbis_min_br->setCurrentIndex(1);
        kcfg_vorbis_nominal_br->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(EncoderVorbisConfig);
    } // setupUi

    void retranslateUi(QWidget *EncoderVorbisConfig)
    {
        kcfg_vorbis_enc_method->setTitle(tr2i18n("&Encoding Method", nullptr));
        vorbis_enc_bitrate->setText(tr2i18n("Bi&trate based", nullptr));
        vorbis_enc_quality->setText(tr2i18n("&Quality based", nullptr));
        vorbis_bitrate_settings->setTitle(tr2i18n("Vorbis Bitrate Settings", nullptr));
        kcfg_set_vorbis_max_br->setText(tr2i18n("Ma&ximal bitrate:", nullptr));
        kcfg_vorbis_max_br->setItemText(0, tr2i18n("32 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(1, tr2i18n("40 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(2, tr2i18n("48 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(3, tr2i18n("56 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(4, tr2i18n("64 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(5, tr2i18n("80 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(6, tr2i18n("96 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(7, tr2i18n("112 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(8, tr2i18n("128 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(9, tr2i18n("160 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(10, tr2i18n("192 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(11, tr2i18n("224 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(12, tr2i18n("256 kbps", nullptr));
        kcfg_vorbis_max_br->setItemText(13, tr2i18n("350 kbps", nullptr));

        kcfg_vorbis_min_br->setItemText(0, tr2i18n("32 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(1, tr2i18n("40 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(2, tr2i18n("48 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(3, tr2i18n("56 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(4, tr2i18n("64 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(5, tr2i18n("80 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(6, tr2i18n("96 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(7, tr2i18n("112 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(8, tr2i18n("128 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(9, tr2i18n("160 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(10, tr2i18n("192 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(11, tr2i18n("224 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(12, tr2i18n("256 kbps", nullptr));
        kcfg_vorbis_min_br->setItemText(13, tr2i18n("350 kbps", nullptr));

        kcfg_set_vorbis_nominal_br->setText(tr2i18n("A&verage bitrate:", nullptr));
        kcfg_set_vorbis_min_br->setText(tr2i18n("M&inimal bitrate:", nullptr));
        kcfg_vorbis_nominal_br->setItemText(0, tr2i18n("128 kbps", nullptr));
        kcfg_vorbis_nominal_br->setItemText(1, tr2i18n("160 kbps", nullptr));
        kcfg_vorbis_nominal_br->setItemText(2, tr2i18n("192 kbps", nullptr));
        kcfg_vorbis_nominal_br->setItemText(3, tr2i18n("256 kbps", nullptr));
        kcfg_vorbis_nominal_br->setItemText(4, tr2i18n("350 kbps", nullptr));

#if QT_CONFIG(whatsthis)
        vorbis_quality_settings->setWhatsThis(tr2i18n("You can set the quality of the encoded stream here. A higher value implies a higher quality but encodes slower.", nullptr));
#endif // QT_CONFIG(whatsthis)
        vorbis_quality_settings->setTitle(tr2i18n("Vorbis &Quality Setting", nullptr));
        qualityLabel->setText(tr2i18n("Quality", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_vorbis_quality->setWhatsThis(tr2i18n("Higher is better but slower", nullptr));
#endif // QT_CONFIG(whatsthis)
        GroupBox193->setTitle(tr2i18n("Options", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_vorbis_comments->setWhatsThis(tr2i18n("Add a description of the song to the file header. This makes it easy for the user to get advanced song information shown by his media player. You can get this information automatically via the Internet. Look at the <i>\"CDDB Retrieval\"</i> control module for details.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_vorbis_comments->setText(tr2i18n("Add &track information", nullptr));
        (void)EncoderVorbisConfig;
    } // retranslateUi

};

namespace Ui {
    class EncoderVorbisConfig: public Ui_EncoderVorbisConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENCODERVORBISCONFIG_H

