// This file is generated by kconfig_compiler_kf6 from audiocd_flac_encoder.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Get Flac compression level
    */
    static
    uint flac_compression_level()
    {
      return self()->mFlac_compression_level;
    }

    /**
      Is Flac compression level Immutable
    */
    static
    bool isFlac_compression_levelImmutable()
    {
      return self()->isImmutable( QStringLiteral( "flac_compression_level" ) );
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // Flac
    uint mFlac_compression_level;
};

#endif

