/********************************************************************************
** Form generated from reading UI file 'audiocdconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUDIOCDCONFIG_H
#define UI_AUDIOCDCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kseparator.h"

QT_BEGIN_NAMESPACE

class Ui_AudiocdConfig
{
public:
    QGridLayout *gridLayout;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QCheckBox *ec_enable_check;
    QCheckBox *ec_skip_check;
    QGroupBox *encoderPriorityGroupBox;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QWidget *encoderPriority;
    QGridLayout *gridLayout1;
    QSlider *niceLevel;
    QLabel *textLabel3;
    QLabel *textLabel4;
    QLabel *textLabel2;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *Spacer5;
    QWidget *tabNames;
    QGridLayout *gridLayout_2;
    QGroupBox *albumNameGroupBox;
    QVBoxLayout *vboxLayout;
    QLabel *fileNameLabel_2;
    QGridLayout *gridLayout2;
    QLabel *textLabel20;
    QLabel *textLabel15;
    QLabel *textLabel16;
    QLabel *textLabel21;
    QLabel *textLabel19;
    QLabel *textLabel18;
    QLabel *textLabel17;
    QLabel *textLabel14;
    QSpacerItem *spacer3;
    QLineEdit *albumNameLineEdit;
    QSpacerItem *spacer4;
    QGroupBox *groupBox2;
    QGridLayout *gridLayout3;
    QLabel *textLabel2_2;
    QLabel *textLabel3_2;
    QLineEdit *example;
    QLabel *textLabel1;
    QLineEdit *kcfg_replaceInput;
    QLabel *inputlabel;
    QLabel *outputLabel;
    QLabel *exampleOutput;
    QFrame *line1;
    QLabel *exampleLabel;
    QLineEdit *kcfg_replaceOutput;
    QGroupBox *fileNameGroupBox;
    QGridLayout *gridLayout_3;
    QLabel *textLabel1_2;
    QGridLayout *gridLayout4;
    QLabel *textLabel13;
    QLabel *textLabel10;
    QLabel *textLabel2_3;
    QLabel *textLabel5;
    QLabel *textLabel11;
    QLabel *textLabel2_4;
    QLabel *textLabel3_3;
    QLabel *textLabel9;
    QLabel *textLabel8;
    QLabel *textLabel12;
    QLabel *textLabel1_3;
    QLabel *textLabel6;
    QLabel *textLabel7;
    QLabel *textLabel4_2;
    QLineEdit *fileNameLineEdit;
    QGroupBox *fileLocationGroupBox;
    QVBoxLayout *_2;
    QCheckBox *fileLocationCheckBox;
    QWidget *fileLocationVerticalWidget;
    QVBoxLayout *fileLocationVerticalLayout;
    QLabel *fileNameLabel_3;
    QGridLayout *_3;
    QLabel *textLabel21_2;
    QLabel *textLabel18_2;
    QLabel *textLabel16_2;
    QLabel *textLabel17_2;
    QLabel *textLabel14_2;
    QLabel *textLabel15_2;
    QLabel *textLabel20_2;
    QLabel *textLabel19_2;
    QSpacerItem *spacer3_2;
    QLineEdit *fileLocationLineEdit;
    KSeparator *kseparator;
    KSeparator *kseparator_2;

    void setupUi(QWidget *AudiocdConfig)
    {
        if (AudiocdConfig->objectName().isEmpty())
            AudiocdConfig->setObjectName("AudiocdConfig");
        AudiocdConfig->resize(825, 527);
        gridLayout = new QGridLayout(AudiocdConfig);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(AudiocdConfig);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabWidget->setDocumentMode(true);
        tabGeneral = new QWidget();
        tabGeneral->setObjectName("tabGeneral");
        verticalLayout = new QVBoxLayout(tabGeneral);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        ec_enable_check = new QCheckBox(tabGeneral);
        ec_enable_check->setObjectName("ec_enable_check");
        ec_enable_check->setChecked(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, ec_enable_check);

        ec_skip_check = new QCheckBox(tabGeneral);
        ec_skip_check->setObjectName("ec_skip_check");
        ec_skip_check->setChecked(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, ec_skip_check);


        verticalLayout->addLayout(formLayout);

        encoderPriorityGroupBox = new QGroupBox(tabGeneral);
        encoderPriorityGroupBox->setObjectName("encoderPriorityGroupBox");
        encoderPriorityGroupBox->setFlat(true);
        horizontalLayout_2 = new QHBoxLayout(encoderPriorityGroupBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        encoderPriority = new QWidget(encoderPriorityGroupBox);
        encoderPriority->setObjectName("encoderPriority");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(encoderPriority->sizePolicy().hasHeightForWidth());
        encoderPriority->setSizePolicy(sizePolicy1);
        encoderPriority->setMinimumSize(QSize(500, 0));
        gridLayout1 = new QGridLayout(encoderPriority);
        gridLayout1->setObjectName("gridLayout1");
        niceLevel = new QSlider(encoderPriority);
        niceLevel->setObjectName("niceLevel");
        niceLevel->setMinimumSize(QSize(350, 0));
        niceLevel->setMinimum(-19);
        niceLevel->setMaximum(19);
        niceLevel->setSingleStep(5);
        niceLevel->setOrientation(Qt::Orientation::Horizontal);
        niceLevel->setTickPosition(QSlider::TickPosition::TicksBelow);
        niceLevel->setTickInterval(1);

        gridLayout1->addWidget(niceLevel, 0, 0, 1, 3);

        textLabel3 = new QLabel(encoderPriority);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        textLabel3->setWordWrap(false);

        gridLayout1->addWidget(textLabel3, 1, 2, 1, 1);

        textLabel4 = new QLabel(encoderPriority);
        textLabel4->setObjectName("textLabel4");
        textLabel4->setAlignment(Qt::AlignmentFlag::AlignCenter);
        textLabel4->setWordWrap(false);

        gridLayout1->addWidget(textLabel4, 1, 1, 1, 1);

        textLabel2 = new QLabel(encoderPriority);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout1->addWidget(textLabel2, 1, 0, 1, 1);


        horizontalLayout_2->addWidget(encoderPriority);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addWidget(encoderPriorityGroupBox);

        Spacer5 = new QSpacerItem(20, 210, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(Spacer5);

        tabWidget->addTab(tabGeneral, QString());
        tabNames = new QWidget();
        tabNames->setObjectName("tabNames");
        gridLayout_2 = new QGridLayout(tabNames);
        gridLayout_2->setObjectName("gridLayout_2");
        albumNameGroupBox = new QGroupBox(tabNames);
        albumNameGroupBox->setObjectName("albumNameGroupBox");
        albumNameGroupBox->setFlat(true);
        vboxLayout = new QVBoxLayout(albumNameGroupBox);
        vboxLayout->setObjectName("vboxLayout");
        fileNameLabel_2 = new QLabel(albumNameGroupBox);
        fileNameLabel_2->setObjectName("fileNameLabel_2");
        fileNameLabel_2->setWordWrap(false);

        vboxLayout->addWidget(fileNameLabel_2);

        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        textLabel20 = new QLabel(albumNameGroupBox);
        textLabel20->setObjectName("textLabel20");
        textLabel20->setWordWrap(false);

        gridLayout2->addWidget(textLabel20, 2, 1, 1, 1);

        textLabel15 = new QLabel(albumNameGroupBox);
        textLabel15->setObjectName("textLabel15");
        textLabel15->setWordWrap(false);

        gridLayout2->addWidget(textLabel15, 1, 0, 1, 1);

        textLabel16 = new QLabel(albumNameGroupBox);
        textLabel16->setObjectName("textLabel16");
        textLabel16->setWordWrap(false);

        gridLayout2->addWidget(textLabel16, 2, 0, 1, 1);

        textLabel21 = new QLabel(albumNameGroupBox);
        textLabel21->setObjectName("textLabel21");
        textLabel21->setWordWrap(false);

        gridLayout2->addWidget(textLabel21, 3, 1, 1, 1);

        textLabel19 = new QLabel(albumNameGroupBox);
        textLabel19->setObjectName("textLabel19");
        textLabel19->setWordWrap(false);

        gridLayout2->addWidget(textLabel19, 1, 1, 1, 1);

        textLabel18 = new QLabel(albumNameGroupBox);
        textLabel18->setObjectName("textLabel18");
        textLabel18->setWordWrap(false);

        gridLayout2->addWidget(textLabel18, 0, 1, 1, 1);

        textLabel17 = new QLabel(albumNameGroupBox);
        textLabel17->setObjectName("textLabel17");
        textLabel17->setWordWrap(false);

        gridLayout2->addWidget(textLabel17, 3, 0, 1, 1);

        textLabel14 = new QLabel(albumNameGroupBox);
        textLabel14->setObjectName("textLabel14");
        textLabel14->setWordWrap(false);

        gridLayout2->addWidget(textLabel14, 0, 0, 1, 1);


        vboxLayout->addLayout(gridLayout2);

        spacer3 = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer3);

        albumNameLineEdit = new QLineEdit(albumNameGroupBox);
        albumNameLineEdit->setObjectName("albumNameLineEdit");

        vboxLayout->addWidget(albumNameLineEdit);


        gridLayout_2->addWidget(albumNameGroupBox, 0, 2, 1, 1);

        spacer4 = new QSpacerItem(21, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(spacer4, 2, 0, 1, 1);

        groupBox2 = new QGroupBox(tabNames);
        groupBox2->setObjectName("groupBox2");
        groupBox2->setFlat(true);
        gridLayout3 = new QGridLayout(groupBox2);
        gridLayout3->setObjectName("gridLayout3");
        textLabel2_2 = new QLabel(groupBox2);
        textLabel2_2->setObjectName("textLabel2_2");
        textLabel2_2->setWordWrap(true);

        gridLayout3->addWidget(textLabel2_2, 1, 0, 1, 1);

        textLabel3_2 = new QLabel(groupBox2);
        textLabel3_2->setObjectName("textLabel3_2");
        textLabel3_2->setWordWrap(false);

        gridLayout3->addWidget(textLabel3_2, 1, 2, 1, 1);

        example = new QLineEdit(groupBox2);
        example->setObjectName("example");

        gridLayout3->addWidget(example, 5, 1, 1, 2);

        textLabel1 = new QLabel(groupBox2);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setAlignment(Qt::AlignmentFlag::AlignVCenter);
        textLabel1->setWordWrap(true);

        gridLayout3->addWidget(textLabel1, 0, 0, 1, 3);

        kcfg_replaceInput = new QLineEdit(groupBox2);
        kcfg_replaceInput->setObjectName("kcfg_replaceInput");

        gridLayout3->addWidget(kcfg_replaceInput, 2, 0, 1, 2);

        inputlabel = new QLabel(groupBox2);
        inputlabel->setObjectName("inputlabel");
        inputlabel->setWordWrap(false);

        gridLayout3->addWidget(inputlabel, 5, 0, 1, 1);

        outputLabel = new QLabel(groupBox2);
        outputLabel->setObjectName("outputLabel");
        outputLabel->setWordWrap(false);

        gridLayout3->addWidget(outputLabel, 6, 0, 1, 1);

        exampleOutput = new QLabel(groupBox2);
        exampleOutput->setObjectName("exampleOutput");
        exampleOutput->setWordWrap(false);

        gridLayout3->addWidget(exampleOutput, 6, 1, 1, 2);

        line1 = new QFrame(groupBox2);
        line1->setObjectName("line1");
        line1->setFrameShape(QFrame::Shape::HLine);
        line1->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout3->addWidget(line1, 3, 0, 1, 3);

        exampleLabel = new QLabel(groupBox2);
        exampleLabel->setObjectName("exampleLabel");
        exampleLabel->setWordWrap(false);

        gridLayout3->addWidget(exampleLabel, 4, 0, 1, 2);

        kcfg_replaceOutput = new QLineEdit(groupBox2);
        kcfg_replaceOutput->setObjectName("kcfg_replaceOutput");

        gridLayout3->addWidget(kcfg_replaceOutput, 2, 2, 1, 1);


        gridLayout_2->addWidget(groupBox2, 1, 0, 1, 5);

        fileNameGroupBox = new QGroupBox(tabNames);
        fileNameGroupBox->setObjectName("fileNameGroupBox");
        fileNameGroupBox->setFlat(true);
        gridLayout_3 = new QGridLayout(fileNameGroupBox);
        gridLayout_3->setObjectName("gridLayout_3");
        textLabel1_2 = new QLabel(fileNameGroupBox);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        gridLayout_3->addWidget(textLabel1_2, 0, 0, 1, 1);

        gridLayout4 = new QGridLayout();
        gridLayout4->setObjectName("gridLayout4");
        textLabel13 = new QLabel(fileNameGroupBox);
        textLabel13->setObjectName("textLabel13");
        textLabel13->setWordWrap(false);

        gridLayout4->addWidget(textLabel13, 6, 1, 1, 1);

        textLabel10 = new QLabel(fileNameGroupBox);
        textLabel10->setObjectName("textLabel10");
        textLabel10->setWordWrap(false);

        gridLayout4->addWidget(textLabel10, 5, 0, 1, 1);

        textLabel2_3 = new QLabel(fileNameGroupBox);
        textLabel2_3->setObjectName("textLabel2_3");
        textLabel2_3->setWordWrap(false);

        gridLayout4->addWidget(textLabel2_3, 0, 0, 1, 1);

        textLabel5 = new QLabel(fileNameGroupBox);
        textLabel5->setObjectName("textLabel5");
        textLabel5->setWordWrap(false);

        gridLayout4->addWidget(textLabel5, 2, 1, 1, 1);

        textLabel11 = new QLabel(fileNameGroupBox);
        textLabel11->setObjectName("textLabel11");
        textLabel11->setWordWrap(false);

        gridLayout4->addWidget(textLabel11, 5, 1, 1, 1);

        textLabel2_4 = new QLabel(fileNameGroupBox);
        textLabel2_4->setObjectName("textLabel2_4");
        textLabel2_4->setWordWrap(false);

        gridLayout4->addWidget(textLabel2_4, 3, 1, 1, 1);

        textLabel3_3 = new QLabel(fileNameGroupBox);
        textLabel3_3->setObjectName("textLabel3_3");
        textLabel3_3->setWordWrap(false);

        gridLayout4->addWidget(textLabel3_3, 0, 1, 1, 1);

        textLabel9 = new QLabel(fileNameGroupBox);
        textLabel9->setObjectName("textLabel9");
        textLabel9->setWordWrap(false);

        gridLayout4->addWidget(textLabel9, 4, 1, 1, 1);

        textLabel8 = new QLabel(fileNameGroupBox);
        textLabel8->setObjectName("textLabel8");
        textLabel8->setWordWrap(false);

        gridLayout4->addWidget(textLabel8, 4, 0, 1, 1);

        textLabel12 = new QLabel(fileNameGroupBox);
        textLabel12->setObjectName("textLabel12");
        textLabel12->setWordWrap(false);

        gridLayout4->addWidget(textLabel12, 6, 0, 1, 1);

        textLabel1_3 = new QLabel(fileNameGroupBox);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setWordWrap(false);

        gridLayout4->addWidget(textLabel1_3, 3, 0, 1, 1);

        textLabel6 = new QLabel(fileNameGroupBox);
        textLabel6->setObjectName("textLabel6");
        textLabel6->setWordWrap(false);

        gridLayout4->addWidget(textLabel6, 2, 0, 1, 1);

        textLabel7 = new QLabel(fileNameGroupBox);
        textLabel7->setObjectName("textLabel7");
        textLabel7->setWordWrap(false);

        gridLayout4->addWidget(textLabel7, 1, 1, 1, 1);

        textLabel4_2 = new QLabel(fileNameGroupBox);
        textLabel4_2->setObjectName("textLabel4_2");
        textLabel4_2->setWordWrap(false);

        gridLayout4->addWidget(textLabel4_2, 1, 0, 1, 1);


        gridLayout_3->addLayout(gridLayout4, 1, 0, 1, 1);

        fileNameLineEdit = new QLineEdit(fileNameGroupBox);
        fileNameLineEdit->setObjectName("fileNameLineEdit");

        gridLayout_3->addWidget(fileNameLineEdit, 2, 0, 1, 1);


        gridLayout_2->addWidget(fileNameGroupBox, 0, 0, 1, 1);

        fileLocationGroupBox = new QGroupBox(tabNames);
        fileLocationGroupBox->setObjectName("fileLocationGroupBox");
        fileLocationGroupBox->setFlat(true);
        fileLocationGroupBox->setCheckable(false);
        fileLocationGroupBox->setChecked(false);
        _2 = new QVBoxLayout(fileLocationGroupBox);
        _2->setObjectName("_2");
        _2->setContentsMargins(-1, -1, -1, 6);
        fileLocationCheckBox = new QCheckBox(fileLocationGroupBox);
        fileLocationCheckBox->setObjectName("fileLocationCheckBox");

        _2->addWidget(fileLocationCheckBox);

        fileLocationVerticalWidget = new QWidget(fileLocationGroupBox);
        fileLocationVerticalWidget->setObjectName("fileLocationVerticalWidget");
        fileLocationVerticalWidget->setEnabled(false);
        fileLocationVerticalLayout = new QVBoxLayout(fileLocationVerticalWidget);
        fileLocationVerticalLayout->setObjectName("fileLocationVerticalLayout");
        fileLocationVerticalLayout->setContentsMargins(0, 0, 0, 0);
        fileNameLabel_3 = new QLabel(fileLocationVerticalWidget);
        fileNameLabel_3->setObjectName("fileNameLabel_3");
        fileNameLabel_3->setWordWrap(false);

        fileLocationVerticalLayout->addWidget(fileNameLabel_3);

        _3 = new QGridLayout();
        _3->setObjectName("_3");
        textLabel21_2 = new QLabel(fileLocationVerticalWidget);
        textLabel21_2->setObjectName("textLabel21_2");
        textLabel21_2->setWordWrap(false);

        _3->addWidget(textLabel21_2, 3, 1, 1, 1);

        textLabel18_2 = new QLabel(fileLocationVerticalWidget);
        textLabel18_2->setObjectName("textLabel18_2");
        textLabel18_2->setWordWrap(false);

        _3->addWidget(textLabel18_2, 0, 1, 1, 1);

        textLabel16_2 = new QLabel(fileLocationVerticalWidget);
        textLabel16_2->setObjectName("textLabel16_2");
        textLabel16_2->setWordWrap(false);

        _3->addWidget(textLabel16_2, 2, 0, 1, 1);

        textLabel17_2 = new QLabel(fileLocationVerticalWidget);
        textLabel17_2->setObjectName("textLabel17_2");
        textLabel17_2->setWordWrap(false);

        _3->addWidget(textLabel17_2, 3, 0, 1, 1);

        textLabel14_2 = new QLabel(fileLocationVerticalWidget);
        textLabel14_2->setObjectName("textLabel14_2");
        textLabel14_2->setWordWrap(false);

        _3->addWidget(textLabel14_2, 0, 0, 1, 1);

        textLabel15_2 = new QLabel(fileLocationVerticalWidget);
        textLabel15_2->setObjectName("textLabel15_2");
        textLabel15_2->setWordWrap(false);

        _3->addWidget(textLabel15_2, 1, 0, 1, 1);

        textLabel20_2 = new QLabel(fileLocationVerticalWidget);
        textLabel20_2->setObjectName("textLabel20_2");
        textLabel20_2->setWordWrap(false);

        _3->addWidget(textLabel20_2, 2, 1, 1, 1);

        textLabel19_2 = new QLabel(fileLocationVerticalWidget);
        textLabel19_2->setObjectName("textLabel19_2");
        textLabel19_2->setWordWrap(false);

        _3->addWidget(textLabel19_2, 1, 1, 1, 1);


        fileLocationVerticalLayout->addLayout(_3);

        spacer3_2 = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        fileLocationVerticalLayout->addItem(spacer3_2);

        fileLocationLineEdit = new QLineEdit(fileLocationVerticalWidget);
        fileLocationLineEdit->setObjectName("fileLocationLineEdit");

        fileLocationVerticalLayout->addWidget(fileLocationLineEdit);


        _2->addWidget(fileLocationVerticalWidget);


        gridLayout_2->addWidget(fileLocationGroupBox, 0, 4, 1, 1);

        kseparator = new KSeparator(tabNames);
        kseparator->setObjectName("kseparator");
        kseparator->setFrameShape(QFrame::Shape::VLine);

        gridLayout_2->addWidget(kseparator, 0, 1, 1, 1);

        kseparator_2 = new KSeparator(tabNames);
        kseparator_2->setObjectName("kseparator_2");
        kseparator_2->setFrameShape(QFrame::Shape::VLine);

        gridLayout_2->addWidget(kseparator_2, 0, 3, 1, 1);

        tabWidget->addTab(tabNames, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 1);

        QWidget::setTabOrder(niceLevel, fileNameLineEdit);
        QWidget::setTabOrder(fileNameLineEdit, albumNameLineEdit);
        QWidget::setTabOrder(albumNameLineEdit, kcfg_replaceInput);
        QWidget::setTabOrder(kcfg_replaceInput, kcfg_replaceOutput);
        QWidget::setTabOrder(kcfg_replaceOutput, example);

        retranslateUi(AudiocdConfig);
        QObject::connect(ec_enable_check, &QCheckBox::toggled, ec_skip_check, &QCheckBox::setEnabled);
        QObject::connect(fileLocationCheckBox, &QCheckBox::clicked, fileLocationVerticalWidget, &QWidget::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AudiocdConfig);
    } // setupUi

    void retranslateUi(QWidget *AudiocdConfig)
    {
#if QT_CONFIG(whatsthis)
        ec_enable_check->setWhatsThis(tr2i18n("If you uncheck this option, the KIO worker will not try to use error correction which can be useful for reading damaged CDs. However, this feature can be problematic in some cases, so you can switch it off here.", nullptr));
#endif // QT_CONFIG(whatsthis)
        ec_enable_check->setText(tr2i18n("Use &error correction when reading the CD", nullptr));
        ec_skip_check->setText(tr2i18n("&Skip on errors", nullptr));
        encoderPriorityGroupBox->setTitle(tr2i18n("Encoder Priority", nullptr));
        textLabel3->setText(tr2i18n("Lowest", nullptr));
        textLabel4->setText(tr2i18n("Normal", nullptr));
        textLabel2->setText(tr2i18n("Highest", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), tr2i18n("&General", nullptr));
        albumNameGroupBox->setTitle(tr2i18n("Album Name", nullptr));
        fileNameLabel_2->setText(tr2i18n("The following macros will be expanded:", nullptr));
        textLabel20->setText(tr2i18n("Year", nullptr));
        textLabel15->setText(tr2i18n("%{albumartist}", nullptr));
        textLabel16->setText(tr2i18n("%{year}", nullptr));
        textLabel21->setText(tr2i18n("Genre", nullptr));
        textLabel19->setText(tr2i18n("Album Artist", nullptr));
        textLabel18->setText(tr2i18n("Album Title", nullptr));
        textLabel17->setText(tr2i18n("%{genre}", nullptr));
        textLabel14->setText(tr2i18n("%{albumtitle}", nullptr));
        groupBox2->setTitle(tr2i18n("Name Regular Expression Replacement", nullptr));
        textLabel2_2->setText(tr2i18n("Selection:", nullptr));
        textLabel3_2->setText(tr2i18n("Replace with:", nullptr));
        example->setText(tr2i18n("Cool artist - example audio file.wav", nullptr));
        textLabel1->setText(tr2i18n("Regular expression used on all file names. For example using selection \" \" and replace with \"_\" would replace all the spaces with underlines.\n"
"", nullptr));
        inputlabel->setText(tr2i18n("Input:", nullptr));
        outputLabel->setText(tr2i18n("Output:", nullptr));
        exampleOutput->setText(tr2i18n("Cool artist - example audio file.wav", nullptr));
        exampleLabel->setText(tr2i18n("Example", nullptr));
        fileNameGroupBox->setTitle(tr2i18n("File Name (without extension)", nullptr));
        textLabel1_2->setText(tr2i18n("The following macros will be expanded:", nullptr));
        textLabel13->setText(tr2i18n("Genre", nullptr));
        textLabel10->setText(tr2i18n("%{year}", nullptr));
        textLabel2_3->setText(tr2i18n("%{title}", nullptr));
        textLabel5->setText(tr2i18n("Album Title", nullptr));
        textLabel11->setText(tr2i18n("Year", nullptr));
        textLabel2_4->setText(tr2i18n("Track Artist", nullptr));
        textLabel3_3->setText(tr2i18n("Track Title", nullptr));
        textLabel9->setText(tr2i18n("Album Artist", nullptr));
        textLabel8->setText(tr2i18n("%{albumartist}", nullptr));
        textLabel12->setText(tr2i18n("%{genre}", nullptr));
        textLabel1_3->setText(tr2i18n("%{trackartist}", nullptr));
        textLabel6->setText(tr2i18n("%{albumtitle}", nullptr));
        textLabel7->setText(tr2i18n("Track Number", nullptr));
        textLabel4_2->setText(tr2i18n("%{number}", nullptr));
#if QT_CONFIG(whatsthis)
        fileLocationGroupBox->setWhatsThis(tr2i18n("This defines where files will appear in relation to the encoder root, you can use / to create subdirectories. E.g: %{albumartist}/%{albumtitle} ", nullptr));
#endif // QT_CONFIG(whatsthis)
        fileLocationGroupBox->setTitle(tr2i18n("File &Location", nullptr));
        fileLocationCheckBox->setText(tr2i18n("Use file location macros", nullptr));
        fileNameLabel_3->setText(tr2i18n("The following macros will be expanded:", nullptr));
        textLabel21_2->setText(tr2i18n("Genre", nullptr));
        textLabel18_2->setText(tr2i18n("Album Title", nullptr));
        textLabel16_2->setText(tr2i18n("%{year}", nullptr));
        textLabel17_2->setText(tr2i18n("%{genre}", nullptr));
        textLabel14_2->setText(tr2i18n("%{albumtitle}", nullptr));
        textLabel15_2->setText(tr2i18n("%{albumartist}", nullptr));
        textLabel20_2->setText(tr2i18n("Year", nullptr));
        textLabel19_2->setText(tr2i18n("Album Artist", nullptr));
        fileLocationLineEdit->setText(tr2i18n("%{albumtitle}/%{albumartist}", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabNames), tr2i18n("&Names", nullptr));
        (void)AudiocdConfig;
    } // retranslateUi

};

namespace Ui {
    class AudiocdConfig: public Ui_AudiocdConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AUDIOCDCONFIG_H

