/********************************************************************************
** Form generated from reading UI file 'encoderlameconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENCODERLAMECONFIG_H
#define UI_ENCODERLAMECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kseparator.h"

QT_BEGIN_NAMESPACE

class Ui_EncoderLameConfig
{
public:
    QGridLayout *gridLayout;
    QGroupBox *GroupBox83_2;
    QGridLayout *gridLayout1;
    QSpinBox *kcfg_highfilterfreq;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_set_lpf_width;
    QCheckBox *kcfg_enable_highpass;
    QSpinBox *kcfg_highfilterwidth;
    QCheckBox *kcfg_set_hpf_width;
    QSpinBox *kcfg_lowfilterfreq;
    QCheckBox *kcfg_enable_lowpass;
    QSpinBox *kcfg_lowfilterwidth;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *vbr_settings;
    QGridLayout *gridLayout2;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *kcfg_vbr_min_br;
    QComboBox *kcfg_vbr_min_brate;
    QCheckBox *kcfg_vbr_average_br;
    QCheckBox *kcfg_vbr_max_br;
    QComboBox *kcfg_vbr_mean_brate;
    QCheckBox *kcfg_vbr_xing_tag;
    QCheckBox *kcfg_vbr_min_hard;
    QComboBox *kcfg_vbr_max_brate;
    QSpacerItem *horizontalSpacer_6;
    QGroupBox *GroupBox1_2;
    QFormLayout *formLayout;
    QCheckBox *kcfg_copyright;
    QCheckBox *kcfg_original;
    QCheckBox *kcfg_iso;
    QCheckBox *kcfg_crc;
    QCheckBox *kcfg_id3_tag;
    QSpacerItem *verticalSpacer;
    QGroupBox *cbr_settings;
    QHBoxLayout *hboxLayout;
    QSpacerItem *horizontalSpacer_3;
    QLabel *TextLabel4_2;
    QComboBox *kcfg_cbr_bitrate;
    QSpacerItem *horizontalSpacer_4;
    QGroupBox *buttonGroup1;
    QFormLayout *formLayout_2;
    QSpacerItem *verticalSpacer2;
    QLabel *bitrateLabel;
    QRadioButton *kcfg_bitrate_constant;
    QRadioButton *kcfg_bitrate_variable;
    QLabel *garfsLabel;
    QComboBox *kcfg_stereo;
    QLabel *qualityLabel;
    QHBoxLayout *hboxLayout1;
    QLabel *TextLabel3_2;
    QSlider *kcfg_quality;
    QLabel *TextLabel2_2;
    QSpacerItem *horizontalSpacer_8;
    KSeparator *kseparator;
    QSpacerItem *spacer11;

    void setupUi(QWidget *EncoderLameConfig)
    {
        if (EncoderLameConfig->objectName().isEmpty())
            EncoderLameConfig->setObjectName("EncoderLameConfig");
        EncoderLameConfig->resize(520, 681);
        gridLayout = new QGridLayout(EncoderLameConfig);
        gridLayout->setObjectName("gridLayout");
        GroupBox83_2 = new QGroupBox(EncoderLameConfig);
        GroupBox83_2->setObjectName("GroupBox83_2");
        GroupBox83_2->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);
        GroupBox83_2->setFlat(true);
        gridLayout1 = new QGridLayout(GroupBox83_2);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        kcfg_highfilterfreq = new QSpinBox(GroupBox83_2);
        kcfg_highfilterfreq->setObjectName("kcfg_highfilterfreq");
        kcfg_highfilterfreq->setEnabled(false);
        kcfg_highfilterfreq->setMaximum(200);

        gridLayout1->addWidget(kcfg_highfilterfreq, 3, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(horizontalSpacer, 2, 0, 1, 1);

        kcfg_set_lpf_width = new QCheckBox(GroupBox83_2);
        kcfg_set_lpf_width->setObjectName("kcfg_set_lpf_width");
        kcfg_set_lpf_width->setEnabled(false);

        gridLayout1->addWidget(kcfg_set_lpf_width, 0, 2, 1, 1);

        kcfg_enable_highpass = new QCheckBox(GroupBox83_2);
        kcfg_enable_highpass->setObjectName("kcfg_enable_highpass");

        gridLayout1->addWidget(kcfg_enable_highpass, 2, 1, 1, 1);

        kcfg_highfilterwidth = new QSpinBox(GroupBox83_2);
        kcfg_highfilterwidth->setObjectName("kcfg_highfilterwidth");
        kcfg_highfilterwidth->setEnabled(false);
        kcfg_highfilterwidth->setMaximum(50);

        gridLayout1->addWidget(kcfg_highfilterwidth, 3, 2, 1, 1);

        kcfg_set_hpf_width = new QCheckBox(GroupBox83_2);
        kcfg_set_hpf_width->setObjectName("kcfg_set_hpf_width");
        kcfg_set_hpf_width->setEnabled(false);

        gridLayout1->addWidget(kcfg_set_hpf_width, 2, 2, 1, 1);

        kcfg_lowfilterfreq = new QSpinBox(GroupBox83_2);
        kcfg_lowfilterfreq->setObjectName("kcfg_lowfilterfreq");
        kcfg_lowfilterfreq->setEnabled(false);
        kcfg_lowfilterfreq->setMaximum(20000);

        gridLayout1->addWidget(kcfg_lowfilterfreq, 1, 1, 1, 1);

        kcfg_enable_lowpass = new QCheckBox(GroupBox83_2);
        kcfg_enable_lowpass->setObjectName("kcfg_enable_lowpass");

        gridLayout1->addWidget(kcfg_enable_lowpass, 0, 1, 1, 1);

        kcfg_lowfilterwidth = new QSpinBox(GroupBox83_2);
        kcfg_lowfilterwidth->setObjectName("kcfg_lowfilterwidth");
        kcfg_lowfilterwidth->setEnabled(false);
        kcfg_lowfilterwidth->setMaximum(5000);

        gridLayout1->addWidget(kcfg_lowfilterwidth, 1, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout1->addItem(horizontalSpacer_2, 2, 3, 1, 1);


        gridLayout->addWidget(GroupBox83_2, 1, 0, 1, 3);

        vbr_settings = new QGroupBox(EncoderLameConfig);
        vbr_settings->setObjectName("vbr_settings");
        vbr_settings->setEnabled(true);
        vbr_settings->setFlat(true);
        gridLayout2 = new QGridLayout(vbr_settings);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName("gridLayout2");
        horizontalSpacer_5 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(horizontalSpacer_5, 2, 3, 1, 1);

        kcfg_vbr_min_br = new QCheckBox(vbr_settings);
        kcfg_vbr_min_br->setObjectName("kcfg_vbr_min_br");
        kcfg_vbr_min_br->setEnabled(false);

        gridLayout2->addWidget(kcfg_vbr_min_br, 0, 1, 1, 1);

        kcfg_vbr_min_brate = new QComboBox(vbr_settings);
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->addItem(QString());
        kcfg_vbr_min_brate->setObjectName("kcfg_vbr_min_brate");
        kcfg_vbr_min_brate->setEnabled(false);

        gridLayout2->addWidget(kcfg_vbr_min_brate, 0, 2, 1, 1);

        kcfg_vbr_average_br = new QCheckBox(vbr_settings);
        kcfg_vbr_average_br->setObjectName("kcfg_vbr_average_br");

        gridLayout2->addWidget(kcfg_vbr_average_br, 3, 1, 1, 1);

        kcfg_vbr_max_br = new QCheckBox(vbr_settings);
        kcfg_vbr_max_br->setObjectName("kcfg_vbr_max_br");
        kcfg_vbr_max_br->setEnabled(false);

        gridLayout2->addWidget(kcfg_vbr_max_br, 2, 1, 1, 1);

        kcfg_vbr_mean_brate = new QComboBox(vbr_settings);
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->addItem(QString());
        kcfg_vbr_mean_brate->setObjectName("kcfg_vbr_mean_brate");
        kcfg_vbr_mean_brate->setEnabled(false);

        gridLayout2->addWidget(kcfg_vbr_mean_brate, 3, 2, 1, 1);

        kcfg_vbr_xing_tag = new QCheckBox(vbr_settings);
        kcfg_vbr_xing_tag->setObjectName("kcfg_vbr_xing_tag");
        kcfg_vbr_xing_tag->setChecked(true);

        gridLayout2->addWidget(kcfg_vbr_xing_tag, 4, 1, 1, 2);

        kcfg_vbr_min_hard = new QCheckBox(vbr_settings);
        kcfg_vbr_min_hard->setObjectName("kcfg_vbr_min_hard");
        kcfg_vbr_min_hard->setEnabled(false);

        gridLayout2->addWidget(kcfg_vbr_min_hard, 1, 1, 1, 2);

        kcfg_vbr_max_brate = new QComboBox(vbr_settings);
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->addItem(QString());
        kcfg_vbr_max_brate->setObjectName("kcfg_vbr_max_brate");
        kcfg_vbr_max_brate->setEnabled(false);

        gridLayout2->addWidget(kcfg_vbr_max_brate, 2, 2, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(horizontalSpacer_6, 2, 0, 1, 1);


        gridLayout->addWidget(vbr_settings, 3, 0, 1, 3);

        GroupBox1_2 = new QGroupBox(EncoderLameConfig);
        GroupBox1_2->setObjectName("GroupBox1_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GroupBox1_2->sizePolicy().hasHeightForWidth());
        GroupBox1_2->setSizePolicy(sizePolicy);
        GroupBox1_2->setFlat(true);
        formLayout = new QFormLayout(GroupBox1_2);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        kcfg_copyright = new QCheckBox(GroupBox1_2);
        kcfg_copyright->setObjectName("kcfg_copyright");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_copyright);

        kcfg_original = new QCheckBox(GroupBox1_2);
        kcfg_original->setObjectName("kcfg_original");
        kcfg_original->setChecked(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, kcfg_original);

        kcfg_iso = new QCheckBox(GroupBox1_2);
        kcfg_iso->setObjectName("kcfg_iso");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, kcfg_iso);

        kcfg_crc = new QCheckBox(GroupBox1_2);
        kcfg_crc->setObjectName("kcfg_crc");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, kcfg_crc);

        kcfg_id3_tag = new QCheckBox(GroupBox1_2);
        kcfg_id3_tag->setObjectName("kcfg_id3_tag");
        kcfg_id3_tag->setChecked(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, kcfg_id3_tag);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(5, QFormLayout::ItemRole::LabelRole, verticalSpacer);


        gridLayout->addWidget(GroupBox1_2, 0, 2, 1, 1);

        cbr_settings = new QGroupBox(EncoderLameConfig);
        cbr_settings->setObjectName("cbr_settings");
        cbr_settings->setFlat(true);
        hboxLayout = new QHBoxLayout(cbr_settings);
#ifndef UI_Q_OS_MACOS
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(11, 11, 11, 11);
        hboxLayout->setObjectName("hboxLayout");
        horizontalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer_3);

        TextLabel4_2 = new QLabel(cbr_settings);
        TextLabel4_2->setObjectName("TextLabel4_2");
        TextLabel4_2->setWordWrap(false);

        hboxLayout->addWidget(TextLabel4_2);

        kcfg_cbr_bitrate = new QComboBox(cbr_settings);
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->addItem(QString());
        kcfg_cbr_bitrate->setObjectName("kcfg_cbr_bitrate");

        hboxLayout->addWidget(kcfg_cbr_bitrate);

        horizontalSpacer_4 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer_4);


        gridLayout->addWidget(cbr_settings, 2, 0, 1, 3);

        buttonGroup1 = new QGroupBox(EncoderLameConfig);
        buttonGroup1->setObjectName("buttonGroup1");
        sizePolicy.setHeightForWidth(buttonGroup1->sizePolicy().hasHeightForWidth());
        buttonGroup1->setSizePolicy(sizePolicy);
        buttonGroup1->setFlat(true);
        formLayout_2 = new QFormLayout(buttonGroup1);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout_2->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        verticalSpacer2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_2->setItem(3, QFormLayout::ItemRole::LabelRole, verticalSpacer2);

        bitrateLabel = new QLabel(buttonGroup1);
        bitrateLabel->setObjectName("bitrateLabel");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, bitrateLabel);

        kcfg_bitrate_constant = new QRadioButton(buttonGroup1);
        kcfg_bitrate_constant->setObjectName("kcfg_bitrate_constant");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_bitrate_constant);

        kcfg_bitrate_variable = new QRadioButton(buttonGroup1);
        kcfg_bitrate_variable->setObjectName("kcfg_bitrate_variable");
        kcfg_bitrate_variable->setChecked(true);

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_bitrate_variable);

        garfsLabel = new QLabel(buttonGroup1);
        garfsLabel->setObjectName("garfsLabel");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, garfsLabel);

        kcfg_stereo = new QComboBox(buttonGroup1);
        kcfg_stereo->addItem(QString());
        kcfg_stereo->addItem(QString());
        kcfg_stereo->addItem(QString());
        kcfg_stereo->addItem(QString());
        kcfg_stereo->setObjectName("kcfg_stereo");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_stereo);

        qualityLabel = new QLabel(buttonGroup1);
        qualityLabel->setObjectName("qualityLabel");

        formLayout_2->setWidget(7, QFormLayout::ItemRole::LabelRole, qualityLabel);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        TextLabel3_2 = new QLabel(buttonGroup1);
        TextLabel3_2->setObjectName("TextLabel3_2");
        TextLabel3_2->setWordWrap(false);

        hboxLayout1->addWidget(TextLabel3_2);

        kcfg_quality = new QSlider(buttonGroup1);
        kcfg_quality->setObjectName("kcfg_quality");
        kcfg_quality->setMinimumSize(QSize(150, 0));
        kcfg_quality->setMinimum(-9);
        kcfg_quality->setMaximum(0);
        kcfg_quality->setPageStep(1);
        kcfg_quality->setValue(-7);
        kcfg_quality->setOrientation(Qt::Orientation::Horizontal);
        kcfg_quality->setTickPosition(QSlider::TickPosition::TicksBelow);
        kcfg_quality->setTickInterval(1);

        hboxLayout1->addWidget(kcfg_quality);

        TextLabel2_2 = new QLabel(buttonGroup1);
        TextLabel2_2->setObjectName("TextLabel2_2");
        TextLabel2_2->setWordWrap(false);

        hboxLayout1->addWidget(TextLabel2_2);

        horizontalSpacer_8 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(horizontalSpacer_8);


        formLayout_2->setLayout(7, QFormLayout::ItemRole::FieldRole, hboxLayout1);


        gridLayout->addWidget(buttonGroup1, 0, 0, 1, 1);

        kseparator = new KSeparator(EncoderLameConfig);
        kseparator->setObjectName("kseparator");
        kseparator->setFrameShape(QFrame::Shape::VLine);

        gridLayout->addWidget(kseparator, 0, 1, 1, 1);

        spacer11 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacer11, 4, 0, 1, 1);

#if QT_CONFIG(shortcut)
        TextLabel4_2->setBuddy(kcfg_cbr_bitrate);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_quality, kcfg_copyright);
        QWidget::setTabOrder(kcfg_copyright, kcfg_original);
        QWidget::setTabOrder(kcfg_original, kcfg_iso);
        QWidget::setTabOrder(kcfg_iso, kcfg_crc);
        QWidget::setTabOrder(kcfg_crc, kcfg_id3_tag);
        QWidget::setTabOrder(kcfg_id3_tag, kcfg_cbr_bitrate);
        QWidget::setTabOrder(kcfg_cbr_bitrate, kcfg_vbr_min_br);
        QWidget::setTabOrder(kcfg_vbr_min_br, kcfg_vbr_min_hard);
        QWidget::setTabOrder(kcfg_vbr_min_hard, kcfg_vbr_max_br);
        QWidget::setTabOrder(kcfg_vbr_max_br, kcfg_vbr_average_br);
        QWidget::setTabOrder(kcfg_vbr_average_br, kcfg_vbr_xing_tag);
        QWidget::setTabOrder(kcfg_vbr_xing_tag, kcfg_vbr_min_brate);
        QWidget::setTabOrder(kcfg_vbr_min_brate, kcfg_vbr_max_brate);
        QWidget::setTabOrder(kcfg_vbr_max_brate, kcfg_vbr_mean_brate);
        QWidget::setTabOrder(kcfg_vbr_mean_brate, kcfg_enable_lowpass);
        QWidget::setTabOrder(kcfg_enable_lowpass, kcfg_lowfilterfreq);
        QWidget::setTabOrder(kcfg_lowfilterfreq, kcfg_enable_highpass);
        QWidget::setTabOrder(kcfg_enable_highpass, kcfg_highfilterfreq);
        QWidget::setTabOrder(kcfg_highfilterfreq, kcfg_set_lpf_width);
        QWidget::setTabOrder(kcfg_set_lpf_width, kcfg_lowfilterwidth);
        QWidget::setTabOrder(kcfg_lowfilterwidth, kcfg_set_hpf_width);
        QWidget::setTabOrder(kcfg_set_hpf_width, kcfg_highfilterwidth);

        retranslateUi(EncoderLameConfig);
        QObject::connect(kcfg_bitrate_constant, &QRadioButton::toggled, cbr_settings, &QGroupBox::setVisible);
        QObject::connect(kcfg_enable_highpass, &QCheckBox::toggled, kcfg_highfilterfreq, &QSpinBox::setEnabled);
        QObject::connect(kcfg_enable_highpass, &QCheckBox::toggled, kcfg_highfilterwidth, &QSpinBox::setEnabled);
        QObject::connect(kcfg_enable_lowpass, &QCheckBox::toggled, kcfg_lowfilterfreq, &QSpinBox::setEnabled);
        QObject::connect(kcfg_enable_lowpass, &QCheckBox::toggled, kcfg_lowfilterwidth, &QSpinBox::setEnabled);
        QObject::connect(kcfg_enable_highpass, &QCheckBox::toggled, kcfg_set_hpf_width, &QCheckBox::setEnabled);
        QObject::connect(kcfg_enable_lowpass, &QCheckBox::toggled, kcfg_set_lpf_width, &QCheckBox::setEnabled);
        QObject::connect(kcfg_vbr_average_br, &QCheckBox::toggled, kcfg_vbr_max_br, &QCheckBox::setEnabled);
        QObject::connect(kcfg_vbr_max_br, &QCheckBox::toggled, kcfg_vbr_max_brate, &QComboBox::setEnabled);
        QObject::connect(kcfg_vbr_average_br, &QCheckBox::toggled, kcfg_vbr_mean_brate, &QComboBox::setEnabled);
        QObject::connect(kcfg_vbr_average_br, &QCheckBox::toggled, kcfg_vbr_min_br, &QCheckBox::setEnabled);
        QObject::connect(kcfg_vbr_min_br, &QCheckBox::toggled, kcfg_vbr_min_brate, &QComboBox::setEnabled);
        QObject::connect(kcfg_vbr_min_br, &QCheckBox::toggled, kcfg_vbr_min_hard, &QCheckBox::setEnabled);
        QObject::connect(kcfg_bitrate_variable, &QRadioButton::toggled, vbr_settings, &QGroupBox::setVisible);

        kcfg_vbr_min_brate->setCurrentIndex(1);
        kcfg_vbr_mean_brate->setCurrentIndex(9);
        kcfg_vbr_max_brate->setCurrentIndex(13);
        kcfg_cbr_bitrate->setCurrentIndex(9);


        QMetaObject::connectSlotsByName(EncoderLameConfig);
    } // setupUi

    void retranslateUi(QWidget *EncoderLameConfig)
    {
        GroupBox83_2->setTitle(tr2i18n("Filter Settings", nullptr));
        kcfg_highfilterfreq->setSuffix(tr2i18n(" Hz", nullptr));
        kcfg_set_lpf_width->setText(tr2i18n("Low&pass filter width", nullptr));
        kcfg_enable_highpass->setText(tr2i18n("Apply &highpass filter below", nullptr));
        kcfg_highfilterwidth->setSuffix(tr2i18n(" Hz", nullptr));
        kcfg_set_hpf_width->setText(tr2i18n("Highpa&ss filter width", nullptr));
        kcfg_lowfilterfreq->setSuffix(tr2i18n(" Hz", nullptr));
        kcfg_enable_lowpass->setText(tr2i18n("Apply &lowpass filter above", nullptr));
        kcfg_lowfilterwidth->setSuffix(tr2i18n(" Hz", nullptr));
        vbr_settings->setTitle(tr2i18n("Variable Bitrate Settings", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_vbr_min_br->setWhatsThis(tr2i18n("This selects the minimal bitrate used for encoding.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_vbr_min_br->setText(tr2i18n("Minimal &bitrate:", nullptr));
        kcfg_vbr_min_brate->setItemText(0, tr2i18n("32 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(1, tr2i18n("40 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(2, tr2i18n("48 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(3, tr2i18n("56 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(4, tr2i18n("64 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(5, tr2i18n("80 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(6, tr2i18n("96 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(7, tr2i18n("112 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(8, tr2i18n("128 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(9, tr2i18n("160 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(10, tr2i18n("192 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(11, tr2i18n("224 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(12, tr2i18n("256 kbs", nullptr));
        kcfg_vbr_min_brate->setItemText(13, tr2i18n("320 kbs", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_vbr_average_br->setWhatsThis(tr2i18n("This selects the average bitrate used for encoding.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_vbr_average_br->setText(tr2i18n("Avera&ge bitrate:", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_vbr_max_br->setWhatsThis(tr2i18n("This selects the maximal bitrate used for encoding.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_vbr_max_br->setText(tr2i18n("Maximal bi&trate:", nullptr));
        kcfg_vbr_mean_brate->setItemText(0, tr2i18n("32 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(1, tr2i18n("40 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(2, tr2i18n("48 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(3, tr2i18n("56 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(4, tr2i18n("64 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(5, tr2i18n("80 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(6, tr2i18n("96 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(7, tr2i18n("112 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(8, tr2i18n("128 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(9, tr2i18n("160 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(10, tr2i18n("192 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(11, tr2i18n("224 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(12, tr2i18n("256 kbs", nullptr));
        kcfg_vbr_mean_brate->setItemText(13, tr2i18n("320 kbs", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_vbr_xing_tag->setWhatsThis(tr2i18n("This writes additional information related to VBR as introduced by Xing.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_vbr_xing_tag->setText(tr2i18n("Write &Xing VBR tag", nullptr));
        kcfg_vbr_min_hard->setText(tr2i18n("Minimal &value is a hard limit", nullptr));
        kcfg_vbr_max_brate->setItemText(0, tr2i18n("32 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(1, tr2i18n("40 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(2, tr2i18n("48 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(3, tr2i18n("56 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(4, tr2i18n("64 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(5, tr2i18n("80 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(6, tr2i18n("96 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(7, tr2i18n("112 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(8, tr2i18n("128 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(9, tr2i18n("160 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(10, tr2i18n("192 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(11, tr2i18n("224 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(12, tr2i18n("256 kbs", nullptr));
        kcfg_vbr_max_brate->setItemText(13, tr2i18n("320 kbs", nullptr));

        GroupBox1_2->setTitle(tr2i18n("Options", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_copyright->setToolTip(tr2i18n("Mark MP3 file as copyrighted", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_copyright->setWhatsThis(tr2i18n("Mark MP3 file as copyrighted.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_copyright->setText(tr2i18n("Cop&yrighted", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_original->setToolTip(tr2i18n("Mark MP3 file as an original", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_original->setWhatsThis(tr2i18n("Mark MP3 file as an original.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_original->setText(tr2i18n("Origi&nal", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_iso->setToolTip(tr2i18n("Try to use strict ISO encoding", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_iso->setWhatsThis(tr2i18n("This selects the maximal bitrate used for encoding.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_iso->setText(tr2i18n("&ISO encoding", nullptr));
        kcfg_crc->setText(tr2i18n("&Error protection", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_id3_tag->setToolTip(tr2i18n("If checked and if cddb support is available, an id3 tag will be appended", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_id3_tag->setWhatsThis(tr2i18n("If checked and if cddb support is available, an id3 tag will be appended", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_id3_tag->setText(tr2i18n("&Write ID3 tag", nullptr));
        cbr_settings->setTitle(tr2i18n("Constant Bitrate Settings", nullptr));
        TextLabel4_2->setText(tr2i18n("Bi&trate:", nullptr));
        kcfg_cbr_bitrate->setItemText(0, tr2i18n("32 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(1, tr2i18n("40 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(2, tr2i18n("48 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(3, tr2i18n("56 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(4, tr2i18n("64 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(5, tr2i18n("80 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(6, tr2i18n("96 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(7, tr2i18n("112 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(8, tr2i18n("128 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(9, tr2i18n("160 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(10, tr2i18n("192 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(11, tr2i18n("224 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(12, tr2i18n("256 kbs", nullptr));
        kcfg_cbr_bitrate->setItemText(13, tr2i18n("320 kbs", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_cbr_bitrate->setWhatsThis(tr2i18n("The higher the bitrate, the better the quality and the larger the file.", nullptr));
#endif // QT_CONFIG(whatsthis)
        buttonGroup1->setTitle(tr2i18n("Encoding Method", nullptr));
        bitrateLabel->setText(tr2i18n("Bitrate:", nullptr));
        kcfg_bitrate_constant->setText(tr2i18n("Co&nstant", nullptr));
        kcfg_bitrate_variable->setText(tr2i18n("Variab&le", nullptr));
        garfsLabel->setText(tr2i18n("Audio channels:", nullptr));
        kcfg_stereo->setItemText(0, tr2i18n("Stereo", nullptr));
        kcfg_stereo->setItemText(1, tr2i18n("Joint Stereo", nullptr));
        kcfg_stereo->setItemText(2, tr2i18n("Dual Channel", nullptr));
        kcfg_stereo->setItemText(3, tr2i18n("Mono", nullptr));

#if QT_CONFIG(whatsthis)
        kcfg_stereo->setWhatsThis(tr2i18n("This option controls whether MP3 files are recorded with one or two channels. Note that choosing <i>\"Mono\"</i> reduces file size, but also kills the stereo signal.", nullptr));
#endif // QT_CONFIG(whatsthis)
        qualityLabel->setText(tr2i18n("Quality:", nullptr));
        TextLabel3_2->setText(tr2i18n("Low", nullptr));
        TextLabel2_2->setText(tr2i18n("High", nullptr));
        (void)EncoderLameConfig;
    } // retranslateUi

};

namespace Ui {
    class EncoderLameConfig: public Ui_EncoderLameConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENCODERLAMECONFIG_H

