/********************************************************************************
** Form generated from reading UI file 'encoderflacconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENCODERFLACCONFIG_H
#define UI_ENCODERFLACCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EncoderFLACConfig
{
public:
    QVBoxLayout *mainLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QHBoxLayout *groupBoxInternalLayout;
    QSlider *horizontalSlider;
    QSpinBox *kcfg_flac_compression_level;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *EncoderFLACConfig)
    {
        if (EncoderFLACConfig->objectName().isEmpty())
            EncoderFLACConfig->setObjectName("EncoderFLACConfig");
        EncoderFLACConfig->resize(263, 150);
        mainLayout = new QVBoxLayout(EncoderFLACConfig);
        mainLayout->setObjectName("mainLayout");
        groupBox = new QGroupBox(EncoderFLACConfig);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        groupBoxInternalLayout = new QHBoxLayout();
        groupBoxInternalLayout->setObjectName("groupBoxInternalLayout");
        horizontalSlider = new QSlider(groupBox);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setMinimumSize(QSize(175, 0));
        horizontalSlider->setMaximum(8);
        horizontalSlider->setValue(5);
        horizontalSlider->setOrientation(Qt::Orientation::Horizontal);
        horizontalSlider->setTickPosition(QSlider::TickPosition::TicksBelow);
        horizontalSlider->setTickInterval(1);

        groupBoxInternalLayout->addWidget(horizontalSlider);

        kcfg_flac_compression_level = new QSpinBox(groupBox);
        kcfg_flac_compression_level->setObjectName("kcfg_flac_compression_level");
        kcfg_flac_compression_level->setMaximum(8);
        kcfg_flac_compression_level->setValue(5);

        groupBoxInternalLayout->addWidget(kcfg_flac_compression_level);


        formLayout->setLayout(0, QFormLayout::ItemRole::LabelRole, groupBoxInternalLayout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(1, QFormLayout::ItemRole::LabelRole, verticalSpacer);


        mainLayout->addWidget(groupBox);


        retranslateUi(EncoderFLACConfig);
        QObject::connect(horizontalSlider, &QSlider::valueChanged, kcfg_flac_compression_level, &QSpinBox::setValue);
        QObject::connect(kcfg_flac_compression_level, &QSpinBox::valueChanged, horizontalSlider, &QSlider::setValue);

        QMetaObject::connectSlotsByName(EncoderFLACConfig);
    } // setupUi

    void retranslateUi(QWidget *EncoderFLACConfig)
    {
        groupBox->setTitle(tr2i18n("Flac Compression Level", nullptr));
        (void)EncoderFLACConfig;
    } // retranslateUi

};

namespace Ui {
    class EncoderFLACConfig: public Ui_EncoderFLACConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENCODERFLACCONFIG_H

