/********************************************************************************
** Form generated from reading UI file 'encoderopusconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENCODEROPUSCONFIG_H
#define UI_ENCODEROPUSCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EncoderOpusConfig
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *opus_enc_method;
    QFormLayout *formLayout;
    QRadioButton *kcfg_opus_enc_complexity;
    QRadioButton *kcfg_opus_enc_bitrate;
    QGroupBox *opus_bitrate_settings;
    QGridLayout *gridLayout;
    QComboBox *kcfg_opus_cbr;
    QRadioButton *kcfg_set_opus_vbr;
    QSpacerItem *horizontalSpacer;
    QRadioButton *kcfg_set_opus_cbr;
    QRadioButton *kcfg_set_opus_cvbr;
    QComboBox *kcfg_opus_vbr;
    QComboBox *kcfg_opus_cvbr;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *opus_complexity_settings;
    QFormLayout *formLayout_3;
    QHBoxLayout *horizontalLayout;
    QSlider *complexitySlider;
    QSpinBox *kcfg_opus_complexity;
    QGroupBox *fileOptions;
    QFormLayout *formLayout_2;
    QCheckBox *kcfg_opus_comments;
    QSpacerItem *spacer9;

    void setupUi(QWidget *EncoderOpusConfig)
    {
        if (EncoderOpusConfig->objectName().isEmpty())
            EncoderOpusConfig->setObjectName("EncoderOpusConfig");
        EncoderOpusConfig->resize(332, 408);
        vboxLayout = new QVBoxLayout(EncoderOpusConfig);
        vboxLayout->setObjectName("vboxLayout");
        opus_enc_method = new QGroupBox(EncoderOpusConfig);
        opus_enc_method->setObjectName("opus_enc_method");
        opus_enc_method->setFlat(true);
        formLayout = new QFormLayout(opus_enc_method);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        kcfg_opus_enc_complexity = new QRadioButton(opus_enc_method);
        kcfg_opus_enc_complexity->setObjectName("kcfg_opus_enc_complexity");
        kcfg_opus_enc_complexity->setChecked(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_opus_enc_complexity);

        kcfg_opus_enc_bitrate = new QRadioButton(opus_enc_method);
        kcfg_opus_enc_bitrate->setObjectName("kcfg_opus_enc_bitrate");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_opus_enc_bitrate);


        vboxLayout->addWidget(opus_enc_method);

        opus_bitrate_settings = new QGroupBox(EncoderOpusConfig);
        opus_bitrate_settings->setObjectName("opus_bitrate_settings");
        opus_bitrate_settings->setEnabled(true);
        opus_bitrate_settings->setFlat(true);
        gridLayout = new QGridLayout(opus_bitrate_settings);
        gridLayout->setObjectName("gridLayout");
        kcfg_opus_cbr = new QComboBox(opus_bitrate_settings);
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->addItem(QString());
        kcfg_opus_cbr->setObjectName("kcfg_opus_cbr");
        kcfg_opus_cbr->setEnabled(false);

        gridLayout->addWidget(kcfg_opus_cbr, 0, 2, 1, 1);

        kcfg_set_opus_vbr = new QRadioButton(opus_bitrate_settings);
        kcfg_set_opus_vbr->setObjectName("kcfg_set_opus_vbr");
        kcfg_set_opus_vbr->setChecked(true);

        gridLayout->addWidget(kcfg_set_opus_vbr, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 0, 1, 1);

        kcfg_set_opus_cbr = new QRadioButton(opus_bitrate_settings);
        kcfg_set_opus_cbr->setObjectName("kcfg_set_opus_cbr");

        gridLayout->addWidget(kcfg_set_opus_cbr, 0, 1, 1, 1);

        kcfg_set_opus_cvbr = new QRadioButton(opus_bitrate_settings);
        kcfg_set_opus_cvbr->setObjectName("kcfg_set_opus_cvbr");

        gridLayout->addWidget(kcfg_set_opus_cvbr, 1, 1, 1, 1);

        kcfg_opus_vbr = new QComboBox(opus_bitrate_settings);
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->addItem(QString());
        kcfg_opus_vbr->setObjectName("kcfg_opus_vbr");
        kcfg_opus_vbr->setEnabled(true);

        gridLayout->addWidget(kcfg_opus_vbr, 2, 2, 1, 1);

        kcfg_opus_cvbr = new QComboBox(opus_bitrate_settings);
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->addItem(QString());
        kcfg_opus_cvbr->setObjectName("kcfg_opus_cvbr");
        kcfg_opus_cvbr->setEnabled(false);

        gridLayout->addWidget(kcfg_opus_cvbr, 1, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 3, 1, 1);


        vboxLayout->addWidget(opus_bitrate_settings);

        opus_complexity_settings = new QGroupBox(EncoderOpusConfig);
        opus_complexity_settings->setObjectName("opus_complexity_settings");
        opus_complexity_settings->setFlat(true);
        formLayout_3 = new QFormLayout(opus_complexity_settings);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout_3->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        complexitySlider = new QSlider(opus_complexity_settings);
        complexitySlider->setObjectName("complexitySlider");
        complexitySlider->setMinimumSize(QSize(200, 0));
        complexitySlider->setMinimum(0);
        complexitySlider->setMaximum(10);
        complexitySlider->setValue(10);
        complexitySlider->setOrientation(Qt::Orientation::Horizontal);
        complexitySlider->setTickPosition(QSlider::TickPosition::TicksBelow);
        complexitySlider->setTickInterval(1);

        horizontalLayout->addWidget(complexitySlider);


        formLayout_3->setLayout(0, QFormLayout::ItemRole::LabelRole, horizontalLayout);

        kcfg_opus_complexity = new QSpinBox(opus_complexity_settings);
        kcfg_opus_complexity->setObjectName("kcfg_opus_complexity");
        kcfg_opus_complexity->setMinimum(0);
        kcfg_opus_complexity->setMaximum(10);
        kcfg_opus_complexity->setValue(10);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_opus_complexity);


        vboxLayout->addWidget(opus_complexity_settings);

        fileOptions = new QGroupBox(EncoderOpusConfig);
        fileOptions->setObjectName("fileOptions");
        fileOptions->setFlat(true);
        formLayout_2 = new QFormLayout(fileOptions);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint);
        formLayout_2->setFormAlignment(Qt::AlignmentFlag::AlignHCenter|Qt::AlignmentFlag::AlignTop);
        kcfg_opus_comments = new QCheckBox(fileOptions);
        kcfg_opus_comments->setObjectName("kcfg_opus_comments");
        kcfg_opus_comments->setEnabled(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_opus_comments);


        vboxLayout->addWidget(fileOptions);

        spacer9 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacer9);


        retranslateUi(EncoderOpusConfig);
        QObject::connect(kcfg_opus_enc_bitrate, &QRadioButton::toggled, opus_bitrate_settings, &QGroupBox::setVisible);
        QObject::connect(kcfg_opus_enc_complexity, &QRadioButton::toggled, opus_complexity_settings, &QGroupBox::setVisible);
        QObject::connect(kcfg_set_opus_cbr, &QRadioButton::toggled, kcfg_opus_cbr, &QComboBox::setEnabled);
        QObject::connect(kcfg_set_opus_cbr, &QRadioButton::toggled, kcfg_opus_cvbr, &QComboBox::setDisabled);
        QObject::connect(kcfg_set_opus_cbr, &QRadioButton::toggled, kcfg_opus_vbr, &QComboBox::setDisabled);
        QObject::connect(kcfg_set_opus_cvbr, &QRadioButton::toggled, kcfg_opus_cvbr, &QComboBox::setEnabled);
        QObject::connect(kcfg_set_opus_cvbr, &QRadioButton::toggled, kcfg_opus_cbr, &QComboBox::setDisabled);
        QObject::connect(kcfg_set_opus_cvbr, &QRadioButton::toggled, kcfg_opus_vbr, &QComboBox::setDisabled);
        QObject::connect(kcfg_set_opus_vbr, &QRadioButton::toggled, kcfg_opus_vbr, &QComboBox::setEnabled);
        QObject::connect(kcfg_set_opus_vbr, &QRadioButton::toggled, kcfg_opus_cvbr, &QComboBox::setDisabled);
        QObject::connect(kcfg_set_opus_vbr, &QRadioButton::toggled, kcfg_opus_cbr, &QComboBox::setDisabled);
        QObject::connect(kcfg_opus_complexity, &QSpinBox::valueChanged, complexitySlider, &QSlider::setValue);
        QObject::connect(complexitySlider, &QSlider::valueChanged, kcfg_opus_complexity, &QSpinBox::setValue);

        kcfg_opus_cbr->setCurrentIndex(6);
        kcfg_opus_vbr->setCurrentIndex(6);
        kcfg_opus_cvbr->setCurrentIndex(6);


        QMetaObject::connectSlotsByName(EncoderOpusConfig);
    } // setupUi

    void retranslateUi(QWidget *EncoderOpusConfig)
    {
        opus_enc_method->setTitle(tr2i18n("&Encoding Method", nullptr));
        kcfg_opus_enc_complexity->setText(tr2i18n("Comp&lexity based", nullptr));
        kcfg_opus_enc_bitrate->setText(tr2i18n("Bi&trate based", nullptr));
        opus_bitrate_settings->setTitle(tr2i18n("Opus Bitrate Settings", nullptr));
        kcfg_opus_cbr->setItemText(0, tr2i18n("6 kbps", nullptr));
        kcfg_opus_cbr->setItemText(1, tr2i18n("12 kbps", nullptr));
        kcfg_opus_cbr->setItemText(2, tr2i18n("24 kbps", nullptr));
        kcfg_opus_cbr->setItemText(3, tr2i18n("48 kbps", nullptr));
        kcfg_opus_cbr->setItemText(4, tr2i18n("64 kbps", nullptr));
        kcfg_opus_cbr->setItemText(5, tr2i18n("80 kbps", nullptr));
        kcfg_opus_cbr->setItemText(6, tr2i18n("96 kbps", nullptr));
        kcfg_opus_cbr->setItemText(7, tr2i18n("128 kbps", nullptr));
        kcfg_opus_cbr->setItemText(8, tr2i18n("160 kbps", nullptr));
        kcfg_opus_cbr->setItemText(9, tr2i18n("192 kbps", nullptr));
        kcfg_opus_cbr->setItemText(10, tr2i18n("256 kbps", nullptr));

        kcfg_opus_cbr->setCurrentText(tr2i18n("96 kbps", nullptr));
        kcfg_set_opus_vbr->setText(tr2i18n("Avera&ge variable bitrate:", nullptr));
        kcfg_set_opus_cbr->setText(tr2i18n("Cons&tant bitrate:", nullptr));
        kcfg_set_opus_cvbr->setText(tr2i18n("Co&nstrained variable bitrate:", nullptr));
        kcfg_opus_vbr->setItemText(0, tr2i18n("6 kbps", nullptr));
        kcfg_opus_vbr->setItemText(1, tr2i18n("12 kbps", nullptr));
        kcfg_opus_vbr->setItemText(2, tr2i18n("24 kbps", nullptr));
        kcfg_opus_vbr->setItemText(3, tr2i18n("48 kbps", nullptr));
        kcfg_opus_vbr->setItemText(4, tr2i18n("64 kbps", nullptr));
        kcfg_opus_vbr->setItemText(5, tr2i18n("80 kbps", nullptr));
        kcfg_opus_vbr->setItemText(6, tr2i18n("96 kbps", nullptr));
        kcfg_opus_vbr->setItemText(7, tr2i18n("128 kbps", nullptr));
        kcfg_opus_vbr->setItemText(8, tr2i18n("160 kbps", nullptr));
        kcfg_opus_vbr->setItemText(9, tr2i18n("192 kbps", nullptr));
        kcfg_opus_vbr->setItemText(10, tr2i18n("256 kbps", nullptr));

        kcfg_opus_vbr->setCurrentText(tr2i18n("96 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(0, tr2i18n("6 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(1, tr2i18n("12 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(2, tr2i18n("24 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(3, tr2i18n("48 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(4, tr2i18n("64 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(5, tr2i18n("80 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(6, tr2i18n("96 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(7, tr2i18n("128 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(8, tr2i18n("160 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(9, tr2i18n("192 kbps", nullptr));
        kcfg_opus_cvbr->setItemText(10, tr2i18n("256 kbps", nullptr));

        kcfg_opus_cvbr->setCurrentText(tr2i18n("96 kbps", nullptr));
#if QT_CONFIG(whatsthis)
        opus_complexity_settings->setWhatsThis(tr2i18n("You can set the complexity of the encoded stream here. A higher value implies a higher complexity but encodes slower.", nullptr));
#endif // QT_CONFIG(whatsthis)
        opus_complexity_settings->setTitle(tr2i18n("Opus Co&mplexity Setting", nullptr));
#if QT_CONFIG(whatsthis)
        complexitySlider->setWhatsThis(tr2i18n("Higher is better but slower", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        kcfg_opus_complexity->setWhatsThis(tr2i18n("Higher is better but slower", nullptr));
#endif // QT_CONFIG(whatsthis)
        fileOptions->setTitle(tr2i18n("Options", nullptr));
#if QT_CONFIG(whatsthis)
        kcfg_opus_comments->setWhatsThis(tr2i18n("Add a description of the song to the file header. This makes it easy for the user to get advanced song information shown by his media player. You can get this information automatically via the Internet. Look at the <i>\"CDDB Retrieval\"</i> control module for details.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_opus_comments->setText(tr2i18n("Add &track information", nullptr));
        (void)EncoderOpusConfig;
    } // retranslateUi

};

namespace Ui {
    class EncoderOpusConfig: public Ui_EncoderOpusConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENCODEROPUSCONFIG_H

