// This file is generated by kconfig_compiler_kf6 from audiocd_vorbis_encoder.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Get Vorbis Encoding Quality or Bitrate
    */
    static
    int vorbis_enc_method()
    {
      return self()->mVorbis_enc_method;
    }

    /**
      Is Vorbis Encoding Quality or Bitrate Immutable
    */
    static
    bool isVorbis_enc_methodImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vorbis_enc_method" ) );
    }

    /**
      Get Minimal bitrate specified
    */
    static
    bool set_vorbis_min_br()
    {
      return self()->mSet_vorbis_min_br;
    }

    /**
      Is Minimal bitrate specified Immutable
    */
    static
    bool isSet_vorbis_min_brImmutable()
    {
      return self()->isImmutable( QStringLiteral( "set_vorbis_min_br" ) );
    }

    /**
      Get Maximal bitrate specified
    */
    static
    bool set_vorbis_max_br()
    {
      return self()->mSet_vorbis_max_br;
    }

    /**
      Is Maximal bitrate specified Immutable
    */
    static
    bool isSet_vorbis_max_brImmutable()
    {
      return self()->isImmutable( QStringLiteral( "set_vorbis_max_br" ) );
    }

    /**
      Get Average bitrate specified
    */
    static
    bool set_vorbis_nominal_br()
    {
      return self()->mSet_vorbis_nominal_br;
    }

    /**
      Is Average bitrate specified Immutable
    */
    static
    bool isSet_vorbis_nominal_brImmutable()
    {
      return self()->isImmutable( QStringLiteral( "set_vorbis_nominal_br" ) );
    }

    /**
      Get Add Comments
    */
    static
    bool vorbis_comments()
    {
      return self()->mVorbis_comments;
    }

    /**
      Is Add Comments Immutable
    */
    static
    bool isVorbis_commentsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vorbis_comments" ) );
    }

    /**
      Get Quality
    */
    static
    double vorbis_quality()
    {
      return self()->mVorbis_quality;
    }

    /**
      Is Quality Immutable
    */
    static
    bool isVorbis_qualityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vorbis_quality" ) );
    }

    /**
      Get Minimal bitrate
    */
    static
    int vorbis_min_br()
    {
      return self()->mVorbis_min_br;
    }

    /**
      Is Minimal bitrate Immutable
    */
    static
    bool isVorbis_min_brImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vorbis_min_br" ) );
    }

    /**
      Get maximal bitrate
    */
    static
    int vorbis_max_br()
    {
      return self()->mVorbis_max_br;
    }

    /**
      Is maximal bitrate Immutable
    */
    static
    bool isVorbis_max_brImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vorbis_max_br" ) );
    }

    /**
      Get maximal bitrate
    */
    static
    int vorbis_nominal_br()
    {
      return self()->mVorbis_nominal_br;
    }

    /**
      Is maximal bitrate Immutable
    */
    static
    bool isVorbis_nominal_brImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vorbis_nominal_br" ) );
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // Vorbis
    int mVorbis_enc_method;
    bool mSet_vorbis_min_br;
    bool mSet_vorbis_max_br;
    bool mSet_vorbis_nominal_br;
    bool mVorbis_comments;
    double mVorbis_quality;
    int mVorbis_min_br;
    int mVorbis_max_br;
    int mVorbis_nominal_br;
};

#endif

