// This file is generated by kconfig_compiler_kf6 from audiocd_opus_encoder.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings() override;

    /**
      Get Vorbis Encoding Complexity or Bitrate
    */
    static
    bool opus_enc_complexity()
    {
      return self()->mOpus_enc_complexity;
    }

    /**
      Is Vorbis Encoding Complexity or Bitrate Immutable
    */
    static
    bool isOpus_enc_complexityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opus_enc_complexity" ) );
    }

    /**
      Get Constant bitrate specified
    */
    static
    bool set_opus_cbr()
    {
      return self()->mSet_opus_cbr;
    }

    /**
      Is Constant bitrate specified Immutable
    */
    static
    bool isSet_opus_cbrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "set_opus_cbr" ) );
    }

    /**
      Get Constrained variable bitrate specified
    */
    static
    bool set_opus_cvbr()
    {
      return self()->mSet_opus_cvbr;
    }

    /**
      Is Constrained variable bitrate specified Immutable
    */
    static
    bool isSet_opus_cvbrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "set_opus_cvbr" ) );
    }

    /**
      Get Average variable bitrate specified
    */
    static
    bool set_opus_vbr()
    {
      return self()->mSet_opus_vbr;
    }

    /**
      Is Average variable bitrate specified Immutable
    */
    static
    bool isSet_opus_vbrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "set_opus_vbr" ) );
    }

    /**
      Get Add Comments
    */
    static
    bool opus_comments()
    {
      return self()->mOpus_comments;
    }

    /**
      Is Add Comments Immutable
    */
    static
    bool isOpus_commentsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opus_comments" ) );
    }

    /**
      Get Complexity
    */
    static
    int opus_complexity()
    {
      return self()->mOpus_complexity;
    }

    /**
      Is Complexity Immutable
    */
    static
    bool isOpus_complexityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opus_complexity" ) );
    }

    /**
      Get Constant bitrate
    */
    static
    int opus_cbr()
    {
      return self()->mOpus_cbr;
    }

    /**
      Is Constant bitrate Immutable
    */
    static
    bool isOpus_cbrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opus_cbr" ) );
    }

    /**
      Get Constrained variable bitrate
    */
    static
    int opus_cvbr()
    {
      return self()->mOpus_cvbr;
    }

    /**
      Is Constrained variable bitrate Immutable
    */
    static
    bool isOpus_cvbrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opus_cvbr" ) );
    }

    /**
      Get Average variable bitrate
    */
    static
    int opus_vbr()
    {
      return self()->mOpus_vbr;
    }

    /**
      Is Average variable bitrate Immutable
    */
    static
    bool isOpus_vbrImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opus_vbr" ) );
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // Vorbis
    bool mOpus_enc_complexity;
    bool mSet_opus_cbr;
    bool mSet_opus_cvbr;
    bool mSet_opus_vbr;
    bool mOpus_comments;
    int mOpus_complexity;
    int mOpus_cbr;
    int mOpus_cvbr;
    int mOpus_vbr;
};

#endif

